@@ -1,6 +1,5 @@
-from .area_interpolate import area_interpolate
-from .area_interpolate import _area_tables_binning
-from .area_join import area_join
+from .area_interpolate import _area_tables_binning, area_interpolate
 from .area_interpolate_dask import area_interpolate_dask
+from .area_join import area_join
 
 __all__ = [area_interpolate, area_join, area_interpolate_dask]
